[BuiltinFunctions::ProhibitBooleanGrep]
[BuiltinFunctions::ProhibitStringyEval]
[BuiltinFunctions::ProhibitStringySplit]
[BuiltinFunctions::ProhibitUniversalCan]
[BuiltinFunctions::ProhibitUniversalIsa]
[ClassHierarchies::ProhibitExplicitISA]
[ControlStructures::ProhibitMutatingListFunctions]
[ControlStructures::ProhibitUnreachableCode]
[ErrorHandling::RequireCarping]
[InputOutput::ProhibitBarewordFileHandles]
[InputOutput::RequireCheckedClose]
[InputOutput::RequireCheckedOpen]
[InputOutput::RequireCheckedSyscalls]
[InputOutput::ProhibitInteractiveTest]
[InputOutput::ProhibitOneArgSelect]
[InputOutput::ProhibitTwoArgOpen]
[Miscellanea::ProhibitFormats]
[Modules::ProhibitEvilModules]
[Modules::RequireEndWithOne]
[Objects::ProhibitIndirectSyntax]
[RegularExpressions::ProhibitCaptureWithoutTest]
[Subroutines::ProhibitBuiltinHomonyms]
[Subroutines::ProhibitExplicitReturnUndef]
[Subroutines::ProhibitReturnSort]
[Subroutines::ProhibitSubroutinePrototypes]
[Subroutines::ProhibitUnusedPrivateSubroutines]
[Subroutines::ProtectPrivateSubs]
[Subroutines::RequireFinalReturn]
[TestingAndDebugging::ProhibitNoStrict]
[TestingAndDebugging::ProhibitProlongedStrictureOverride]
[TestingAndDebugging::RequireUseStrict]
[TestingAndDebugging::RequireUseWarnings]
[TestingAndDebugging::ProhibitNoWarnings]
[ValuesAndExpressions::ProhibitCommaSeparatedStatements]
[ValuesAndExpressions::ProhibitLeadingZeros]
[ValuesAndExpressions::ProhibitMagicNumbers]
[ValuesAndExpressions::ProhibitMismatchedOperators]
[ValuesAndExpressions::ProhibitMixedBooleanOperators]
[Variables::ProhibitPerl4PackageNames]
[Variables::ProhibitUnusedVariables]
[Variables::ProtectPrivateVars]
[Variables::RequireInitializationForLocalVars]
[Variables::RequireLexicalLoopIterators]
[Variables::RequireLocalizedPunctuationVars]
